# Autonomize SDK for Python

The Autonomize SDK for Python provides a comprehensive set of tools and utilities for integrating with Autonomize services. This SDK includes modules for telemetry, monitoring, and other essential services.

## Modules

The Autonomize SDK provides specialized modules for different aspects of application development and monitoring. Below is a detailed overview of each module:

### [Telemetry](./autonomize_sdk/telemetry/README.md)

The Telemetry module provides comprehensive observability for your applications through OpenTelemetry integration.

- **Distributed Tracing**: Track requests across service boundaries
- **Metrics Collection**: Monitor application performance and business metrics
- **Structured Logging**: Centralized logging with context and correlation
- **Automatic Instrumentation**: Built-in support for popular frameworks
- **Custom Measurements**: Create and track your own metrics and traces

## Installation

Install using pip:

```bash
pip install autonomize-sdk-python
```

Or using Poetry:

```bash
poetry add autonomize-sdk-python
```

## Development Setup

1. Clone the repository:
```bash
git clone https://github.com/autonomize-ai/autonomize-sdk-python.git
```

2. Install dependencies using Poetry:
```bash
poetry install
```

3. Set up pre-commit hooks:
```bash
poetry run pre-commit install
```

## Contributing

We love your input! We want to make contributing as easy and transparent as possible.

Please read our [**Contributing Guide**](CONTRIBUTING.md) before making any changes.

Together, we can make Autonomize SDK better! 🌟
